@@ -18,6 +18,7 @@
 #include "biji-date-time.h"
 #include "biji-note-id.h"
 #include "biji-manager.h"
+#include "../bjb-utils.h"
 #include "biji-note-obj.h"
 #include "biji-timeout.h"
 #include "biji-tracker.h"
@@ -267,30 +268,47 @@ biji_note_obj_is_trashed                    (BijiNoteObj *self)
 }
 
 
-static const gchar *
-biji_note_obj_get_path (BijiItem *item)
+const gchar *
+biji_note_obj_get_path (BijiNoteObj *self)
 {
-  BijiNoteObjPrivate *priv;
-
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), NULL);
-
-  priv = biji_note_obj_get_instance_private (BIJI_NOTE_OBJ (item));
+  BijiNoteObjPrivate *priv = biji_note_obj_get_instance_private (self);
 
   return biji_note_id_get_path (priv->id);
 }
 
 static const gchar *
-biji_note_obj_get_title (BijiItem *item)
+biji_note_obj_get_path_from_item (BijiItem *item)
 {
-  BijiNoteObjPrivate *priv;
-
   g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), NULL);
 
-  priv = biji_note_obj_get_instance_private (BIJI_NOTE_OBJ (item));
+  return biji_note_obj_get_path (BIJI_NOTE_OBJ (item));
+}
+
+void
+biji_note_obj_set_path (BijiNoteObj *self,
+                        const char  *path)
+{
+  BijiNoteObjPrivate *priv = biji_note_obj_get_instance_private (self);
+
+  biji_note_id_set_path (priv->id, path);
+}
+
+const char *
+biji_note_obj_get_title (BijiNoteObj *self)
+{
+  BijiNoteObjPrivate *priv = biji_note_obj_get_instance_private (self);
 
   return biji_note_id_get_title (priv->id);
 }
 
+static const gchar *
+biji_note_obj_get_title_from_item (BijiItem *item)
+{
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), NULL);
+
+  return biji_note_obj_get_title (BIJI_NOTE_OBJ (item));
+}
+
 /* If already a title, then note is renamed */
 gboolean
 biji_note_obj_set_title (BijiNoteObj *note, const gchar *proposed_title)
@@ -357,17 +375,16 @@ biji_note_obj_get_mtime (BijiItem *note)
   return biji_note_id_get_mtime (priv->id);
 }
 
-const gchar *
+gchar *
 biji_note_obj_get_last_change_date_string (BijiNoteObj *self)
 {
   BijiNoteObjPrivate *priv;
 
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (self), "");
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (self), g_strdup (""));
 
   priv = biji_note_obj_get_instance_private (self);
 
-  return biji_get_time_diff_with_time (
-             biji_note_id_get_mtime (priv->id));
+  return bjb_utils_get_human_time (biji_note_id_get_mtime (priv->id));
 }
 
 
@@ -1083,8 +1100,8 @@ biji_note_obj_class_init (BijiNoteObjClass *klass)
 
   /* Interface
    * is_collectable is implemented at higher level, eg local_note */
-  item_class->get_title = biji_note_obj_get_title;
-  item_class->get_uuid = biji_note_obj_get_path;
+  item_class->get_title = biji_note_obj_get_title_from_item;
+  item_class->get_uuid = biji_note_obj_get_path_from_item;
   item_class->get_icon = biji_note_obj_get_icon;
   item_class->get_emblem = biji_note_obj_get_emblem;
   item_class->get_pristine = biji_note_obj_get_pristine;
